<?php

/**
 * @file
 * Administration related functions.
 */

/**
 * General settings form.
 */
function taxiselect_admin_settings() {
  $form['taxiselect_suggestions_limit'] = array(
    '#type' => 'select',
    '#title' => t('Taxiselect suggestion limit'),
    '#default_value' => variable_get('taxiselect_suggestions_limit', 3),
    '#options' => drupal_map_assoc(array(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 15, 20, 25)),
    '#description' => t('Shows a number of suggestions if the term matches multiple values or is not found on form submission. You must use the string [suggestions] in the forms error message strings for these to show.'),
    '#required' => TRUE,
  );
  $form['taxiselect_trigger_length'] = array(
    '#type' => 'select',
    '#title' => t('Taxiselect trigger length'),
    '#default_value' => variable_get('taxiselect_trigger_length', 3),
    '#options' => drupal_map_assoc(array(1, 2, 3, 4, 5, 6, 7, 8, 9, 10)),
    '#description' => t('Minimum number of characters before returning an AJAX response. Useful to reduce server load.'),
    '#required' => TRUE,
  );
  $form['taxiselect_response_limit'] = array(
    '#type' => 'select',
    '#title' => t('Taxiselect response limit'),
    '#default_value' => variable_get('taxiselect_response_limit', 10),
    '#options' => drupal_map_assoc(array(1, 2, 3, 4, 5, 10, 15, 20, 25, 30, 40, 50, 75, 100, 200, 250, 500)),
    '#description' => t('Maximum number of results to return per AJAX response. Useful to increase response times/reduce server load or to offer more choices to the user.'),
    '#required' => TRUE,
  );
  $form['taxiselect_node_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Content types to associate this widget with'),
    '#default_value' => array_filter(variable_get('taxiselect_node_types', array())),
    '#options' => array_map('check_plain', node_get_types('names')),
    '#description' => t('A list of node content types you want to use the taxiselect element with.'),
  );
  $form['taxiselect_skip_root'] = array(
    '#type' => 'checkbox',
    '#title' => t('Hide top level categories.'),
    '#default_value' => variable_get('taxiselect_skip_root', 0),
    '#description' => t('If enabled, the root level will be ignored. For example, say the top level is continents, such as Asia, and the second level is countries, this option will hide the continent terms. This restricts selection of the root terms.'),
  );
  $vocabularies = array();
  $v = taxonomy_get_vocabularies();
  foreach ($v as $vocabulary) {
    $vocabularies[$vocabulary->vid] = check_plain($vocabulary->name);
  }
  $form['taxiselect_vocabularies'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Vocabularies to associate this widget with'),
    '#default_value' => array_filter(variable_get('taxiselect_vocabularies', array())),
    '#options' => $vocabularies,
    '#description' => t('A list of vocabularies you want to use the taxiselect element with. Remember that if the taxonomy is not rendered as a single select list, it can not be replaced by the taxiselect widget.'),
  );

  $form['multiple_matches'] = array(
    '#type' => 'fieldset',
    '#title' => t('Multiple term matches found message'),
    '#description' => '<p>'. t('This allows you to override the custom error message for each vocabulary. The standard error message is:') .'</p>'
      .'<ul><li>'. _taxiselect_message('multiple') .'</li><ul>',
  );

  $form['not_found'] = array(
    '#type' => 'fieldset',
    '#title' => t('Term not found message'),
    '#collapsible' => TRUE,
    '#description' => '<p>'. t('This allows you to override the custom error message for each vocabulary. The standard error message is:') .'</p>'
      .'<ul><li>'. _taxiselect_message('not found') .'</li><ul>',
  );

  $form['free_tagging'] = array(
    '#type' => 'fieldset',
    '#title' => t('Psuedo free tagging'),
    '#collapsible' => TRUE,
    '#description' => '<p>'. t('Free tagging removes the hierarchical structure in vocabularies. This option provides a way to free tag new terms into the vocabulary. If the "%hide" option is selected, the new term is appended to the first parental match.', array('%hide' => t('Hide top level categories.'))) .'</p>',
  );

  // custom error messages
  foreach ($v as $vocabulary) {
    $form['not_found']['taxiselect_message_not_found_'. $vocabulary->vid] = array(
      '#type' => 'textfield',
      '#title' => t('Custom message for %vocab', array('%vocab' => $vocabulary->name)),
      '#size' => 80,
      '#maxlength' => 255,
      '#default_value' => variable_get('taxiselect_message_not_found_'. $vocabulary->vid, ''),
    );
    $form['multiple_matches']['taxiselect_message_multiple_matches_'. $vocabulary->vid] = array(
      '#type' => 'textfield',
      '#title' => t('Custom message for %vocab', array('%vocab' => $vocabulary->name)),
      '#size' => 80,
      '#maxlength' => 255,
      '#default_value' => variable_get('taxiselect_message_multiple_matches_'. $vocabulary->vid, ''),
    );
    $form['free_tagging']['taxiselect_free_tagging_'. $vocabulary->vid] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable free tagging via taxiselect for %vocab', array('%vocab' => $vocabulary->name)),
      '#size' => 80,
      '#maxlength' => 255,
      '#default_value' => variable_get('taxiselect_free_tagging_'. $vocabulary->vid, 0),
    );
  }
  return system_settings_form($form);
}
